# finances-api-model

AmzSpApi::FinancesApiModel - the Ruby gem for the Selling Partner API for Finances

The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v0
- Package version: 0.1.0
- Build package: io.swagger.codegen.v3.generators.ruby.RubyClientCodegen
For more information, please visit [https://sellercentral.amazon.com/gp/mws/contactus.html](https://sellercentral.amazon.com/gp/mws/contactus.html)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build finances-api-model.gemspec
```

Then either install the gem locally:

```shell
gem install ./finances-api-model-0.1.0.gem
```
(for development, run `gem install --dev ./finances-api-model-0.1.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'finances-api-model', '~> 0.1.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'finances-api-model', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'finances-api-model'

api_instance = AmzSpApi::FinancesApiModel::DefaultApi.new
opts = { 
  max_results_per_page: 100, # Integer | The maximum number of results to return per page.
  financial_event_group_started_before: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | A date used for selecting financial event groups that opened before (but not at) a specified date and time, in ISO 8601 format. The date-time  must be later than FinancialEventGroupStartedAfter and no later than two minutes before the request was submitted. If FinancialEventGroupStartedAfter and FinancialEventGroupStartedBefore are more than 180 days apart, no financial event groups are returned.
  financial_event_group_started_after: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | A date used for selecting financial event groups that opened after (or at) a specified date and time, in ISO 8601 format. The date-time must be no later than two minutes before the request was submitted.
  next_token: 'next_token_example' # String | A string token returned in the response of your previous request.
}

begin
  result = api_instance.list_financial_event_groups(opts)
  p result
rescue AmzSpApi::FinancesApiModel::ApiError => e
  puts "Exception when calling DefaultApi->list_financial_event_groups: #{e}"
end

api_instance = AmzSpApi::FinancesApiModel::DefaultApi.new
opts = { 
  max_results_per_page: 100, # Integer | The maximum number of results to return per page.
  posted_after: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | A date used for selecting financial events posted after (or at) a specified time. The date-time must be no later than two minutes before the request was submitted, in ISO 8601 date time format.
  posted_before: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | A date used for selecting financial events posted before (but not at) a specified time. The date-time must be later than PostedAfter and no later than two minutes before the request was submitted, in ISO 8601 date time format. If PostedAfter and PostedBefore are more than 180 days apart, no financial events are returned. You must specify the PostedAfter parameter if you specify the PostedBefore parameter. Default: Now minus two minutes.
  next_token: 'next_token_example' # String | A string token returned in the response of your previous request.
}

begin
  result = api_instance.list_financial_events(opts)
  p result
rescue AmzSpApi::FinancesApiModel::ApiError => e
  puts "Exception when calling DefaultApi->list_financial_events: #{e}"
end

api_instance = AmzSpApi::FinancesApiModel::DefaultApi.new
event_group_id = 'event_group_id_example' # String | The identifier of the financial event group to which the events belong.
opts = { 
  max_results_per_page: 100, # Integer | The maximum number of results to return per page.
  next_token: 'next_token_example' # String | A string token returned in the response of your previous request.
}

begin
  result = api_instance.list_financial_events_by_group_id(event_group_id, opts)
  p result
rescue AmzSpApi::FinancesApiModel::ApiError => e
  puts "Exception when calling DefaultApi->list_financial_events_by_group_id: #{e}"
end

api_instance = AmzSpApi::FinancesApiModel::DefaultApi.new
order_id = 'order_id_example' # String | An Amazon-defined order identifier, in 3-7-7 format.
opts = { 
  max_results_per_page: 100, # Integer | The maximum number of results to return per page.
  next_token: 'next_token_example' # String | A string token returned in the response of your previous request.
}

begin
  result = api_instance.list_financial_events_by_order_id(order_id, opts)
  p result
rescue AmzSpApi::FinancesApiModel::ApiError => e
  puts "Exception when calling DefaultApi->list_financial_events_by_order_id: #{e}"
end
```

## Documentation for API Endpoints

All URIs are relative to *https://sellingpartnerapi-na.amazon.com/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AmzSpApi::FinancesApiModel::DefaultApi* | [**list_financial_event_groups**](docs/DefaultApi.md#list_financial_event_groups) | **GET** /finances/v0/financialEventGroups | 
*AmzSpApi::FinancesApiModel::DefaultApi* | [**list_financial_events**](docs/DefaultApi.md#list_financial_events) | **GET** /finances/v0/financialEvents | 
*AmzSpApi::FinancesApiModel::DefaultApi* | [**list_financial_events_by_group_id**](docs/DefaultApi.md#list_financial_events_by_group_id) | **GET** /finances/v0/financialEventGroups/{eventGroupId}/financialEvents | 
*AmzSpApi::FinancesApiModel::DefaultApi* | [**list_financial_events_by_order_id**](docs/DefaultApi.md#list_financial_events_by_order_id) | **GET** /finances/v0/orders/{orderId}/financialEvents | 

## Documentation for Models

 - [AmzSpApi::FinancesApiModel::AdjustmentEvent](docs/AdjustmentEvent.md)
 - [AmzSpApi::FinancesApiModel::AdjustmentEventList](docs/AdjustmentEventList.md)
 - [AmzSpApi::FinancesApiModel::AdjustmentItem](docs/AdjustmentItem.md)
 - [AmzSpApi::FinancesApiModel::AdjustmentItemList](docs/AdjustmentItemList.md)
 - [AmzSpApi::FinancesApiModel::AffordabilityExpenseEvent](docs/AffordabilityExpenseEvent.md)
 - [AmzSpApi::FinancesApiModel::AffordabilityExpenseEventList](docs/AffordabilityExpenseEventList.md)
 - [AmzSpApi::FinancesApiModel::BigDecimal](docs/BigDecimal.md)
 - [AmzSpApi::FinancesApiModel::ChargeComponent](docs/ChargeComponent.md)
 - [AmzSpApi::FinancesApiModel::ChargeComponentList](docs/ChargeComponentList.md)
 - [AmzSpApi::FinancesApiModel::ChargeInstrument](docs/ChargeInstrument.md)
 - [AmzSpApi::FinancesApiModel::ChargeInstrumentList](docs/ChargeInstrumentList.md)
 - [AmzSpApi::FinancesApiModel::CouponPaymentEvent](docs/CouponPaymentEvent.md)
 - [AmzSpApi::FinancesApiModel::CouponPaymentEventList](docs/CouponPaymentEventList.md)
 - [AmzSpApi::FinancesApiModel::Currency](docs/Currency.md)
 - [AmzSpApi::FinancesApiModel::Date](docs/Date.md)
 - [AmzSpApi::FinancesApiModel::DebtRecoveryEvent](docs/DebtRecoveryEvent.md)
 - [AmzSpApi::FinancesApiModel::DebtRecoveryEventList](docs/DebtRecoveryEventList.md)
 - [AmzSpApi::FinancesApiModel::DebtRecoveryItem](docs/DebtRecoveryItem.md)
 - [AmzSpApi::FinancesApiModel::DebtRecoveryItemList](docs/DebtRecoveryItemList.md)
 - [AmzSpApi::FinancesApiModel::DirectPayment](docs/DirectPayment.md)
 - [AmzSpApi::FinancesApiModel::DirectPaymentList](docs/DirectPaymentList.md)
 - [AmzSpApi::FinancesApiModel::Error](docs/Error.md)
 - [AmzSpApi::FinancesApiModel::ErrorList](docs/ErrorList.md)
 - [AmzSpApi::FinancesApiModel::FBALiquidationEvent](docs/FBALiquidationEvent.md)
 - [AmzSpApi::FinancesApiModel::FBALiquidationEventList](docs/FBALiquidationEventList.md)
 - [AmzSpApi::FinancesApiModel::FeeComponent](docs/FeeComponent.md)
 - [AmzSpApi::FinancesApiModel::FeeComponentList](docs/FeeComponentList.md)
 - [AmzSpApi::FinancesApiModel::FinancialEventGroup](docs/FinancialEventGroup.md)
 - [AmzSpApi::FinancesApiModel::FinancialEventGroupList](docs/FinancialEventGroupList.md)
 - [AmzSpApi::FinancesApiModel::FinancialEvents](docs/FinancialEvents.md)
 - [AmzSpApi::FinancesApiModel::ImagingServicesFeeEvent](docs/ImagingServicesFeeEvent.md)
 - [AmzSpApi::FinancesApiModel::ImagingServicesFeeEventList](docs/ImagingServicesFeeEventList.md)
 - [AmzSpApi::FinancesApiModel::ListFinancialEventGroupsPayload](docs/ListFinancialEventGroupsPayload.md)
 - [AmzSpApi::FinancesApiModel::ListFinancialEventGroupsResponse](docs/ListFinancialEventGroupsResponse.md)
 - [AmzSpApi::FinancesApiModel::ListFinancialEventsPayload](docs/ListFinancialEventsPayload.md)
 - [AmzSpApi::FinancesApiModel::ListFinancialEventsResponse](docs/ListFinancialEventsResponse.md)
 - [AmzSpApi::FinancesApiModel::LoanServicingEvent](docs/LoanServicingEvent.md)
 - [AmzSpApi::FinancesApiModel::LoanServicingEventList](docs/LoanServicingEventList.md)
 - [AmzSpApi::FinancesApiModel::NetworkComminglingTransactionEvent](docs/NetworkComminglingTransactionEvent.md)
 - [AmzSpApi::FinancesApiModel::NetworkComminglingTransactionEventList](docs/NetworkComminglingTransactionEventList.md)
 - [AmzSpApi::FinancesApiModel::PayWithAmazonEvent](docs/PayWithAmazonEvent.md)
 - [AmzSpApi::FinancesApiModel::PayWithAmazonEventList](docs/PayWithAmazonEventList.md)
 - [AmzSpApi::FinancesApiModel::ProductAdsPaymentEvent](docs/ProductAdsPaymentEvent.md)
 - [AmzSpApi::FinancesApiModel::ProductAdsPaymentEventList](docs/ProductAdsPaymentEventList.md)
 - [AmzSpApi::FinancesApiModel::Promotion](docs/Promotion.md)
 - [AmzSpApi::FinancesApiModel::PromotionList](docs/PromotionList.md)
 - [AmzSpApi::FinancesApiModel::RemovalShipmentEvent](docs/RemovalShipmentEvent.md)
 - [AmzSpApi::FinancesApiModel::RemovalShipmentEventList](docs/RemovalShipmentEventList.md)
 - [AmzSpApi::FinancesApiModel::RemovalShipmentItem](docs/RemovalShipmentItem.md)
 - [AmzSpApi::FinancesApiModel::RemovalShipmentItemList](docs/RemovalShipmentItemList.md)
 - [AmzSpApi::FinancesApiModel::RentalTransactionEvent](docs/RentalTransactionEvent.md)
 - [AmzSpApi::FinancesApiModel::RentalTransactionEventList](docs/RentalTransactionEventList.md)
 - [AmzSpApi::FinancesApiModel::RetrochargeEvent](docs/RetrochargeEvent.md)
 - [AmzSpApi::FinancesApiModel::RetrochargeEventList](docs/RetrochargeEventList.md)
 - [AmzSpApi::FinancesApiModel::SAFETReimbursementEvent](docs/SAFETReimbursementEvent.md)
 - [AmzSpApi::FinancesApiModel::SAFETReimbursementEventList](docs/SAFETReimbursementEventList.md)
 - [AmzSpApi::FinancesApiModel::SAFETReimbursementItem](docs/SAFETReimbursementItem.md)
 - [AmzSpApi::FinancesApiModel::SAFETReimbursementItemList](docs/SAFETReimbursementItemList.md)
 - [AmzSpApi::FinancesApiModel::SellerDealPaymentEvent](docs/SellerDealPaymentEvent.md)
 - [AmzSpApi::FinancesApiModel::SellerDealPaymentEventList](docs/SellerDealPaymentEventList.md)
 - [AmzSpApi::FinancesApiModel::SellerReviewEnrollmentPaymentEvent](docs/SellerReviewEnrollmentPaymentEvent.md)
 - [AmzSpApi::FinancesApiModel::SellerReviewEnrollmentPaymentEventList](docs/SellerReviewEnrollmentPaymentEventList.md)
 - [AmzSpApi::FinancesApiModel::ServiceFeeEvent](docs/ServiceFeeEvent.md)
 - [AmzSpApi::FinancesApiModel::ServiceFeeEventList](docs/ServiceFeeEventList.md)
 - [AmzSpApi::FinancesApiModel::ShipmentEvent](docs/ShipmentEvent.md)
 - [AmzSpApi::FinancesApiModel::ShipmentEventList](docs/ShipmentEventList.md)
 - [AmzSpApi::FinancesApiModel::ShipmentItem](docs/ShipmentItem.md)
 - [AmzSpApi::FinancesApiModel::ShipmentItemList](docs/ShipmentItemList.md)
 - [AmzSpApi::FinancesApiModel::SolutionProviderCreditEvent](docs/SolutionProviderCreditEvent.md)
 - [AmzSpApi::FinancesApiModel::SolutionProviderCreditEventList](docs/SolutionProviderCreditEventList.md)
 - [AmzSpApi::FinancesApiModel::TDSReimbursementEvent](docs/TDSReimbursementEvent.md)
 - [AmzSpApi::FinancesApiModel::TDSReimbursementEventList](docs/TDSReimbursementEventList.md)
 - [AmzSpApi::FinancesApiModel::TaxWithheldComponent](docs/TaxWithheldComponent.md)
 - [AmzSpApi::FinancesApiModel::TaxWithheldComponentList](docs/TaxWithheldComponentList.md)
 - [AmzSpApi::FinancesApiModel::TrialShipmentEvent](docs/TrialShipmentEvent.md)
 - [AmzSpApi::FinancesApiModel::TrialShipmentEventList](docs/TrialShipmentEventList.md)

## Documentation for Authorization

 All endpoints do not require authorization.

