# messaging-api-model

AmzSpApi::MessagingApiModel - the Ruby gem for the Selling Partner API for Messaging

With the Messaging API you can build applications that send messages to buyers. You can get a list of message types that are available for an order that you specify, then call an operation that sends a message to the buyer for that order. The Messaging API returns responses that are formed according to the <a href=https://tools.ietf.org/html/draft-kelly-json-hal-08>JSON Hypertext Application Language</a> (HAL) standard.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v1
- Package version: 0.1.0
- Build package: io.swagger.codegen.v3.generators.ruby.RubyClientCodegen
For more information, please visit [https://sellercentral.amazon.com/gp/mws/contactus.html](https://sellercentral.amazon.com/gp/mws/contactus.html)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build messaging-api-model.gemspec
```

Then either install the gem locally:

```shell
gem install ./messaging-api-model-0.1.0.gem
```
(for development, run `gem install --dev ./messaging-api-model-0.1.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'messaging-api-model', '~> 0.1.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'messaging-api-model', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'messaging-api-model'

api_instance = AmzSpApi::MessagingApiModel::MessagingApi.new
body = AmzSpApi::MessagingApiModel::CreateConfirmCustomizationDetailsRequest.new # CreateConfirmCustomizationDetailsRequest | 
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which a message is sent.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.confirm_customization_details(body, amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::MessagingApiModel::ApiError => e
  puts "Exception when calling MessagingApi->confirm_customization_details: #{e}"
end

api_instance = AmzSpApi::MessagingApiModel::MessagingApi.new
body = AmzSpApi::MessagingApiModel::CreateAmazonMotorsRequest.new # CreateAmazonMotorsRequest | 
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which a message is sent.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.create_amazon_motors(body, amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::MessagingApiModel::ApiError => e
  puts "Exception when calling MessagingApi->create_amazon_motors: #{e}"
end

api_instance = AmzSpApi::MessagingApiModel::MessagingApi.new
body = AmzSpApi::MessagingApiModel::CreateConfirmDeliveryDetailsRequest.new # CreateConfirmDeliveryDetailsRequest | 
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which a message is sent.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.create_confirm_delivery_details(body, amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::MessagingApiModel::ApiError => e
  puts "Exception when calling MessagingApi->create_confirm_delivery_details: #{e}"
end

api_instance = AmzSpApi::MessagingApiModel::MessagingApi.new
body = AmzSpApi::MessagingApiModel::CreateConfirmOrderDetailsRequest.new # CreateConfirmOrderDetailsRequest | 
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which a message is sent.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.create_confirm_order_details(body, amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::MessagingApiModel::ApiError => e
  puts "Exception when calling MessagingApi->create_confirm_order_details: #{e}"
end

api_instance = AmzSpApi::MessagingApiModel::MessagingApi.new
body = AmzSpApi::MessagingApiModel::CreateConfirmServiceDetailsRequest.new # CreateConfirmServiceDetailsRequest | 
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which a message is sent.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.create_confirm_service_details(body, amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::MessagingApiModel::ApiError => e
  puts "Exception when calling MessagingApi->create_confirm_service_details: #{e}"
end

api_instance = AmzSpApi::MessagingApiModel::MessagingApi.new
body = AmzSpApi::MessagingApiModel::CreateDigitalAccessKeyRequest.new # CreateDigitalAccessKeyRequest | 
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which a message is sent.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.create_digital_access_key(body, amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::MessagingApiModel::ApiError => e
  puts "Exception when calling MessagingApi->create_digital_access_key: #{e}"
end

api_instance = AmzSpApi::MessagingApiModel::MessagingApi.new
body = AmzSpApi::MessagingApiModel::CreateLegalDisclosureRequest.new # CreateLegalDisclosureRequest | 
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which a message is sent.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.create_legal_disclosure(body, amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::MessagingApiModel::ApiError => e
  puts "Exception when calling MessagingApi->create_legal_disclosure: #{e}"
end

api_instance = AmzSpApi::MessagingApiModel::MessagingApi.new
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which a message is sent.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.create_negative_feedback_removal(amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::MessagingApiModel::ApiError => e
  puts "Exception when calling MessagingApi->create_negative_feedback_removal: #{e}"
end

api_instance = AmzSpApi::MessagingApiModel::MessagingApi.new
body = AmzSpApi::MessagingApiModel::CreateUnexpectedProblemRequest.new # CreateUnexpectedProblemRequest | 
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which a message is sent.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.create_unexpected_problem(body, amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::MessagingApiModel::ApiError => e
  puts "Exception when calling MessagingApi->create_unexpected_problem: #{e}"
end

api_instance = AmzSpApi::MessagingApiModel::MessagingApi.new
body = AmzSpApi::MessagingApiModel::CreateWarrantyRequest.new # CreateWarrantyRequest | 
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which a message is sent.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.create_warranty(body, amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::MessagingApiModel::ApiError => e
  puts "Exception when calling MessagingApi->create_warranty: #{e}"
end

api_instance = AmzSpApi::MessagingApiModel::MessagingApi.new
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which a message is sent.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.get_attributes(amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::MessagingApiModel::ApiError => e
  puts "Exception when calling MessagingApi->get_attributes: #{e}"
end

api_instance = AmzSpApi::MessagingApiModel::MessagingApi.new
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which you want a list of available message types.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.get_messaging_actions_for_order(amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::MessagingApiModel::ApiError => e
  puts "Exception when calling MessagingApi->get_messaging_actions_for_order: #{e}"
end
```

## Documentation for API Endpoints

All URIs are relative to *https://sellingpartnerapi-na.amazon.com/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AmzSpApi::MessagingApiModel::MessagingApi* | [**confirm_customization_details**](docs/MessagingApi.md#confirm_customization_details) | **POST** /messaging/v1/orders/{amazonOrderId}/messages/confirmCustomizationDetails | 
*AmzSpApi::MessagingApiModel::MessagingApi* | [**create_amazon_motors**](docs/MessagingApi.md#create_amazon_motors) | **POST** /messaging/v1/orders/{amazonOrderId}/messages/amazonMotors | 
*AmzSpApi::MessagingApiModel::MessagingApi* | [**create_confirm_delivery_details**](docs/MessagingApi.md#create_confirm_delivery_details) | **POST** /messaging/v1/orders/{amazonOrderId}/messages/confirmDeliveryDetails | 
*AmzSpApi::MessagingApiModel::MessagingApi* | [**create_confirm_order_details**](docs/MessagingApi.md#create_confirm_order_details) | **POST** /messaging/v1/orders/{amazonOrderId}/messages/confirmOrderDetails | 
*AmzSpApi::MessagingApiModel::MessagingApi* | [**create_confirm_service_details**](docs/MessagingApi.md#create_confirm_service_details) | **POST** /messaging/v1/orders/{amazonOrderId}/messages/confirmServiceDetails | 
*AmzSpApi::MessagingApiModel::MessagingApi* | [**create_digital_access_key**](docs/MessagingApi.md#create_digital_access_key) | **POST** /messaging/v1/orders/{amazonOrderId}/messages/digitalAccessKey | 
*AmzSpApi::MessagingApiModel::MessagingApi* | [**create_legal_disclosure**](docs/MessagingApi.md#create_legal_disclosure) | **POST** /messaging/v1/orders/{amazonOrderId}/messages/legalDisclosure | 
*AmzSpApi::MessagingApiModel::MessagingApi* | [**create_negative_feedback_removal**](docs/MessagingApi.md#create_negative_feedback_removal) | **POST** /messaging/v1/orders/{amazonOrderId}/messages/negativeFeedbackRemoval | 
*AmzSpApi::MessagingApiModel::MessagingApi* | [**create_unexpected_problem**](docs/MessagingApi.md#create_unexpected_problem) | **POST** /messaging/v1/orders/{amazonOrderId}/messages/unexpectedProblem | 
*AmzSpApi::MessagingApiModel::MessagingApi* | [**create_warranty**](docs/MessagingApi.md#create_warranty) | **POST** /messaging/v1/orders/{amazonOrderId}/messages/warranty | 
*AmzSpApi::MessagingApiModel::MessagingApi* | [**get_attributes**](docs/MessagingApi.md#get_attributes) | **GET** /messaging/v1/orders/{amazonOrderId}/attributes | 
*AmzSpApi::MessagingApiModel::MessagingApi* | [**get_messaging_actions_for_order**](docs/MessagingApi.md#get_messaging_actions_for_order) | **GET** /messaging/v1/orders/{amazonOrderId} | 

## Documentation for Models

 - [AmzSpApi::MessagingApiModel::Attachment](docs/Attachment.md)
 - [AmzSpApi::MessagingApiModel::CreateAmazonMotorsRequest](docs/CreateAmazonMotorsRequest.md)
 - [AmzSpApi::MessagingApiModel::CreateAmazonMotorsResponse](docs/CreateAmazonMotorsResponse.md)
 - [AmzSpApi::MessagingApiModel::CreateConfirmCustomizationDetailsRequest](docs/CreateConfirmCustomizationDetailsRequest.md)
 - [AmzSpApi::MessagingApiModel::CreateConfirmCustomizationDetailsResponse](docs/CreateConfirmCustomizationDetailsResponse.md)
 - [AmzSpApi::MessagingApiModel::CreateConfirmDeliveryDetailsRequest](docs/CreateConfirmDeliveryDetailsRequest.md)
 - [AmzSpApi::MessagingApiModel::CreateConfirmDeliveryDetailsResponse](docs/CreateConfirmDeliveryDetailsResponse.md)
 - [AmzSpApi::MessagingApiModel::CreateConfirmOrderDetailsRequest](docs/CreateConfirmOrderDetailsRequest.md)
 - [AmzSpApi::MessagingApiModel::CreateConfirmOrderDetailsResponse](docs/CreateConfirmOrderDetailsResponse.md)
 - [AmzSpApi::MessagingApiModel::CreateConfirmServiceDetailsRequest](docs/CreateConfirmServiceDetailsRequest.md)
 - [AmzSpApi::MessagingApiModel::CreateConfirmServiceDetailsResponse](docs/CreateConfirmServiceDetailsResponse.md)
 - [AmzSpApi::MessagingApiModel::CreateDigitalAccessKeyRequest](docs/CreateDigitalAccessKeyRequest.md)
 - [AmzSpApi::MessagingApiModel::CreateDigitalAccessKeyResponse](docs/CreateDigitalAccessKeyResponse.md)
 - [AmzSpApi::MessagingApiModel::CreateLegalDisclosureRequest](docs/CreateLegalDisclosureRequest.md)
 - [AmzSpApi::MessagingApiModel::CreateLegalDisclosureResponse](docs/CreateLegalDisclosureResponse.md)
 - [AmzSpApi::MessagingApiModel::CreateNegativeFeedbackRemovalResponse](docs/CreateNegativeFeedbackRemovalResponse.md)
 - [AmzSpApi::MessagingApiModel::CreateUnexpectedProblemRequest](docs/CreateUnexpectedProblemRequest.md)
 - [AmzSpApi::MessagingApiModel::CreateUnexpectedProblemResponse](docs/CreateUnexpectedProblemResponse.md)
 - [AmzSpApi::MessagingApiModel::CreateWarrantyRequest](docs/CreateWarrantyRequest.md)
 - [AmzSpApi::MessagingApiModel::CreateWarrantyResponse](docs/CreateWarrantyResponse.md)
 - [AmzSpApi::MessagingApiModel::Error](docs/Error.md)
 - [AmzSpApi::MessagingApiModel::ErrorList](docs/ErrorList.md)
 - [AmzSpApi::MessagingApiModel::GetAttributesResponse](docs/GetAttributesResponse.md)
 - [AmzSpApi::MessagingApiModel::GetAttributesResponseBuyer](docs/GetAttributesResponseBuyer.md)
 - [AmzSpApi::MessagingApiModel::GetMessagingActionResponse](docs/GetMessagingActionResponse.md)
 - [AmzSpApi::MessagingApiModel::GetMessagingActionResponseEmbedded](docs/GetMessagingActionResponseEmbedded.md)
 - [AmzSpApi::MessagingApiModel::GetMessagingActionResponseLinks](docs/GetMessagingActionResponseLinks.md)
 - [AmzSpApi::MessagingApiModel::GetMessagingActionsForOrderResponse](docs/GetMessagingActionsForOrderResponse.md)
 - [AmzSpApi::MessagingApiModel::GetMessagingActionsForOrderResponseEmbedded](docs/GetMessagingActionsForOrderResponseEmbedded.md)
 - [AmzSpApi::MessagingApiModel::GetMessagingActionsForOrderResponseLinks](docs/GetMessagingActionsForOrderResponseLinks.md)
 - [AmzSpApi::MessagingApiModel::GetSchemaResponse](docs/GetSchemaResponse.md)
 - [AmzSpApi::MessagingApiModel::GetSchemaResponseLinks](docs/GetSchemaResponseLinks.md)
 - [AmzSpApi::MessagingApiModel::LinkObject](docs/LinkObject.md)
 - [AmzSpApi::MessagingApiModel::MessagingAction](docs/MessagingAction.md)
 - [AmzSpApi::MessagingApiModel::Schema](docs/Schema.md)

## Documentation for Authorization

 All endpoints do not require authorization.

