# orders-api-model

AmzSpApi::OrdersApiModel - the Ruby gem for the Selling Partner API for Orders

The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v0
- Package version: 0.1.0
- Build package: io.swagger.codegen.v3.generators.ruby.RubyClientCodegen
For more information, please visit [https://sellercentral.amazon.com/gp/mws/contactus.html](https://sellercentral.amazon.com/gp/mws/contactus.html)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build orders-api-model.gemspec
```

Then either install the gem locally:

```shell
gem install ./orders-api-model-0.1.0.gem
```
(for development, run `gem install --dev ./orders-api-model-0.1.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'orders-api-model', '~> 0.1.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'orders-api-model', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'orders-api-model'

api_instance = AmzSpApi::OrdersApiModel::OrdersV0Api.new
order_id = 'order_id_example' # String | An Amazon-defined order identifier, in 3-7-7 format.


begin
  result = api_instance.get_order(order_id)
  p result
rescue AmzSpApi::OrdersApiModel::ApiError => e
  puts "Exception when calling OrdersV0Api->get_order: #{e}"
end

api_instance = AmzSpApi::OrdersApiModel::OrdersV0Api.new
order_id = 'order_id_example' # String | An orderId is an Amazon-defined order identifier, in 3-7-7 format.


begin
  result = api_instance.get_order_address(order_id)
  p result
rescue AmzSpApi::OrdersApiModel::ApiError => e
  puts "Exception when calling OrdersV0Api->get_order_address: #{e}"
end

api_instance = AmzSpApi::OrdersApiModel::OrdersV0Api.new
order_id = 'order_id_example' # String | An orderId is an Amazon-defined order identifier, in 3-7-7 format.


begin
  result = api_instance.get_order_buyer_info(order_id)
  p result
rescue AmzSpApi::OrdersApiModel::ApiError => e
  puts "Exception when calling OrdersV0Api->get_order_buyer_info: #{e}"
end

api_instance = AmzSpApi::OrdersApiModel::OrdersV0Api.new
order_id = 'order_id_example' # String | An Amazon-defined order identifier, in 3-7-7 format.
opts = { 
  next_token: 'next_token_example' # String | A string token returned in the response of your previous request.
}

begin
  result = api_instance.get_order_items(order_id, opts)
  p result
rescue AmzSpApi::OrdersApiModel::ApiError => e
  puts "Exception when calling OrdersV0Api->get_order_items: #{e}"
end

api_instance = AmzSpApi::OrdersApiModel::OrdersV0Api.new
order_id = 'order_id_example' # String | An Amazon-defined order identifier, in 3-7-7 format.
opts = { 
  next_token: 'next_token_example' # String | A string token returned in the response of your previous request.
}

begin
  result = api_instance.get_order_items_buyer_info(order_id, opts)
  p result
rescue AmzSpApi::OrdersApiModel::ApiError => e
  puts "Exception when calling OrdersV0Api->get_order_items_buyer_info: #{e}"
end

api_instance = AmzSpApi::OrdersApiModel::OrdersV0Api.new
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A list of MarketplaceId values. Used to select orders that were placed in the specified marketplaces.
opts = { 
  created_after: 'created_after_example', # String | A date used for selecting orders created after (or at) a specified time. Only orders placed after the specified time are returned. Either the CreatedAfter parameter or the LastUpdatedAfter parameter is required. Both cannot be empty. The date must be in ISO 8601 format.
  created_before: 'created_before_example', # String | A date used for selecting orders created before (or at) a specified time. Only orders placed before the specified time are returned. The date must be in ISO 8601 format.
  last_updated_after: 'last_updated_after_example', # String | A date used for selecting orders that were last updated after (or at) a specified time. An update is defined as any change in order status, including the creation of a new order. Includes updates made by Amazon and by the seller. The date must be in ISO 8601 format.
  last_updated_before: 'last_updated_before_example', # String | A date used for selecting orders that were last updated before (or at) a specified time. An update is defined as any change in order status, including the creation of a new order. Includes updates made by Amazon and by the seller. The date must be in ISO 8601 format.
  order_statuses: ['order_statuses_example'], # Array<String> | A list of OrderStatus values used to filter the results. Possible values: PendingAvailability (This status is available for pre-orders only. The order has been placed, payment has not been authorized, and the release date of the item is in the future.); Pending (The order has been placed but payment has not been authorized); Unshipped (Payment has been authorized and the order is ready for shipment, but no items in the order have been shipped); PartiallyShipped (One or more, but not all, items in the order have been shipped); Shipped (All items in the order have been shipped); InvoiceUnconfirmed (All items in the order have been shipped. The seller has not yet given confirmation to Amazon that the invoice has been shipped to the buyer.); Canceled (The order has been canceled); and Unfulfillable (The order cannot be fulfilled. This state applies only to Multi-Channel Fulfillment orders.).
  fulfillment_channels: ['fulfillment_channels_example'], # Array<String> | A list that indicates how an order was fulfilled. Filters the results by fulfillment channel. Possible values: FBA (Fulfillment by Amazon); SellerFulfilled (Fulfilled by the seller).
  payment_methods: ['payment_methods_example'], # Array<String> | A list of payment method values. Used to select orders paid using the specified payment methods. Possible values: COD (Cash on delivery); CVS (Convenience store payment); Other (Any payment method other than COD or CVS).
  buyer_email: 'buyer_email_example', # String | The email address of a buyer. Used to select orders that contain the specified email address.
  seller_order_id: 'seller_order_id_example', # String | An order identifier that is specified by the seller. Used to select only the orders that match the order identifier. If SellerOrderId is specified, then FulfillmentChannels, OrderStatuses, PaymentMethod, LastUpdatedAfter, LastUpdatedBefore, and BuyerEmail cannot be specified.
  max_results_per_page: 56, # Integer | A number that indicates the maximum number of orders that can be returned per page. Value must be 1 - 100. Default 100.
  easy_ship_shipment_statuses: ['easy_ship_shipment_statuses_example'], # Array<String> | A list of EasyShipShipmentStatus values. Used to select Easy Ship orders with statuses that match the specified  values. If EasyShipShipmentStatus is specified, only Amazon Easy Ship orders are returned.Possible values: PendingPickUp (Amazon has not yet picked up the package from the seller). LabelCanceled (The seller canceled the pickup). PickedUp (Amazon has picked up the package from the seller). AtOriginFC (The packaged is at the origin fulfillment center). AtDestinationFC (The package is at the destination fulfillment center). OutForDelivery (The package is out for delivery). Damaged (The package was damaged by the carrier). Delivered (The package has been delivered to the buyer). RejectedByBuyer (The package has been rejected by the buyer). Undeliverable (The package cannot be delivered). ReturnedToSeller (The package was not delivered to the buyer and was returned to the seller). ReturningToSeller (The package was not delivered to the buyer and is being returned to the seller).
  next_token: 'next_token_example', # String | A string token returned in the response of your previous request.
  amazon_order_ids: ['amazon_order_ids_example'] # Array<String> | A list of AmazonOrderId values. An AmazonOrderId is an Amazon-defined order identifier, in 3-7-7 format.
}

begin
  result = api_instance.get_orders(marketplace_ids, opts)
  p result
rescue AmzSpApi::OrdersApiModel::ApiError => e
  puts "Exception when calling OrdersV0Api->get_orders: #{e}"
end
```

## Documentation for API Endpoints

All URIs are relative to *https://sellingpartnerapi-na.amazon.com/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AmzSpApi::OrdersApiModel::OrdersV0Api* | [**get_order**](docs/OrdersV0Api.md#get_order) | **GET** /orders/v0/orders/{orderId} | 
*AmzSpApi::OrdersApiModel::OrdersV0Api* | [**get_order_address**](docs/OrdersV0Api.md#get_order_address) | **GET** /orders/v0/orders/{orderId}/address | 
*AmzSpApi::OrdersApiModel::OrdersV0Api* | [**get_order_buyer_info**](docs/OrdersV0Api.md#get_order_buyer_info) | **GET** /orders/v0/orders/{orderId}/buyerInfo | 
*AmzSpApi::OrdersApiModel::OrdersV0Api* | [**get_order_items**](docs/OrdersV0Api.md#get_order_items) | **GET** /orders/v0/orders/{orderId}/orderItems | 
*AmzSpApi::OrdersApiModel::OrdersV0Api* | [**get_order_items_buyer_info**](docs/OrdersV0Api.md#get_order_items_buyer_info) | **GET** /orders/v0/orders/{orderId}/orderItems/buyerInfo | 
*AmzSpApi::OrdersApiModel::OrdersV0Api* | [**get_orders**](docs/OrdersV0Api.md#get_orders) | **GET** /orders/v0/orders | 

## Documentation for Models

 - [AmzSpApi::OrdersApiModel::Address](docs/Address.md)
 - [AmzSpApi::OrdersApiModel::BuyerCustomizedInfoDetail](docs/BuyerCustomizedInfoDetail.md)
 - [AmzSpApi::OrdersApiModel::BuyerTaxInfo](docs/BuyerTaxInfo.md)
 - [AmzSpApi::OrdersApiModel::Error](docs/Error.md)
 - [AmzSpApi::OrdersApiModel::ErrorList](docs/ErrorList.md)
 - [AmzSpApi::OrdersApiModel::FulfillmentInstruction](docs/FulfillmentInstruction.md)
 - [AmzSpApi::OrdersApiModel::GetOrderAddressResponse](docs/GetOrderAddressResponse.md)
 - [AmzSpApi::OrdersApiModel::GetOrderBuyerInfoResponse](docs/GetOrderBuyerInfoResponse.md)
 - [AmzSpApi::OrdersApiModel::GetOrderItemsBuyerInfoResponse](docs/GetOrderItemsBuyerInfoResponse.md)
 - [AmzSpApi::OrdersApiModel::GetOrderItemsResponse](docs/GetOrderItemsResponse.md)
 - [AmzSpApi::OrdersApiModel::GetOrderResponse](docs/GetOrderResponse.md)
 - [AmzSpApi::OrdersApiModel::GetOrdersResponse](docs/GetOrdersResponse.md)
 - [AmzSpApi::OrdersApiModel::Money](docs/Money.md)
 - [AmzSpApi::OrdersApiModel::Order](docs/Order.md)
 - [AmzSpApi::OrdersApiModel::OrderAddress](docs/OrderAddress.md)
 - [AmzSpApi::OrdersApiModel::OrderBuyerInfo](docs/OrderBuyerInfo.md)
 - [AmzSpApi::OrdersApiModel::OrderItem](docs/OrderItem.md)
 - [AmzSpApi::OrdersApiModel::OrderItemBuyerInfo](docs/OrderItemBuyerInfo.md)
 - [AmzSpApi::OrdersApiModel::OrderItemBuyerInfoList](docs/OrderItemBuyerInfoList.md)
 - [AmzSpApi::OrdersApiModel::OrderItemList](docs/OrderItemList.md)
 - [AmzSpApi::OrdersApiModel::OrderItemsBuyerInfoList](docs/OrderItemsBuyerInfoList.md)
 - [AmzSpApi::OrdersApiModel::OrderItemsList](docs/OrderItemsList.md)
 - [AmzSpApi::OrdersApiModel::OrderList](docs/OrderList.md)
 - [AmzSpApi::OrdersApiModel::OrdersList](docs/OrdersList.md)
 - [AmzSpApi::OrdersApiModel::PaymentExecutionDetailItem](docs/PaymentExecutionDetailItem.md)
 - [AmzSpApi::OrdersApiModel::PaymentExecutionDetailItemList](docs/PaymentExecutionDetailItemList.md)
 - [AmzSpApi::OrdersApiModel::PaymentMethodDetailItemList](docs/PaymentMethodDetailItemList.md)
 - [AmzSpApi::OrdersApiModel::PointsGrantedDetail](docs/PointsGrantedDetail.md)
 - [AmzSpApi::OrdersApiModel::ProductInfoDetail](docs/ProductInfoDetail.md)
 - [AmzSpApi::OrdersApiModel::PromotionIdList](docs/PromotionIdList.md)
 - [AmzSpApi::OrdersApiModel::TaxClassification](docs/TaxClassification.md)
 - [AmzSpApi::OrdersApiModel::TaxCollection](docs/TaxCollection.md)

## Documentation for Authorization

 All endpoints do not require authorization.

