# sales-api-model

AmzSpApi::SalesApiModel - the Ruby gem for the Selling Partner API for Sales

The Selling Partner API for Sales provides APIs related to sales performance.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v1
- Package version: 0.1.0
- Build package: io.swagger.codegen.v3.generators.ruby.RubyClientCodegen
For more information, please visit [https://sellercentral.amazon.com/gp/mws/contactus.html](https://sellercentral.amazon.com/gp/mws/contactus.html)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build sales-api-model.gemspec
```

Then either install the gem locally:

```shell
gem install ./sales-api-model-0.1.0.gem
```
(for development, run `gem install --dev ./sales-api-model-0.1.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'sales-api-model', '~> 0.1.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'sales-api-model', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'sales-api-model'

api_instance = AmzSpApi::SalesApiModel::SalesApi.new
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A list of marketplace identifiers. Example: ATVPDKIKX0DER indicates the US marketplace.
interval = 'interval_example' # String | A time interval used for selecting order metrics. This takes the form of two dates separated by two hyphens (first date is inclusive; second date is exclusive). Dates are in ISO8601 format and must represent absolute time (either Z notation or offset notation). Example: 2018-09-01T00:00:00-07:00--2018-09-04T00:00:00-07:00 requests order metrics for Sept 1st, 2nd and 3rd in the -07:00 zone.
granularity = 'granularity_example' # String | The granularity of the grouping of order metrics, based on a unit of time. Specifying granularity=Hour results in a successful request only if the interval specified is less than or equal to 30 days from now. For all other granularities, the interval specified must be less or equal to 2 years from now. Specifying granularity=Total results in order metrics that are aggregated over the entire interval that you specify. If the interval start and end date don’t align with the specified granularity, the head and tail end of the response interval will contain partial data. Example: Day to get a daily breakdown of the request interval, where the day boundary is defined by the granularityTimeZone.
opts = { 
  granularity_time_zone: 'granularity_time_zone_example', # String | An IANA-compatible time zone for determining the day boundary. Required when specifying a granularity value greater than Hour. The granularityTimeZone value must align with the offset of the specified interval value. For example, if the interval value uses Z notation, then granularityTimeZone must be UTC. If the interval value uses an offset, then granularityTimeZone must be an IANA-compatible time zone that matches the offset. Example: US/Pacific to compute day boundaries, accounting for daylight time savings, for US/Pacific zone.
  buyer_type: 'All', # String | Filters the results by the buyer type that you specify, B2B (business to business) or B2C (business to customer). Example: B2B, if you want the response to include order metrics for only B2B buyers.
  fulfillment_network: 'fulfillment_network_example', # String | Filters the results by the fulfillment network that you specify, MFN (merchant fulfillment network) or AFN (Amazon fulfillment network). Do not include this filter if you want the response to include order metrics for all fulfillment networks. Example: AFN, if you want the response to include order metrics for only Amazon fulfillment network.
  first_day_of_week: 'Monday', # String | Specifies the day that the week starts on when granularity=Week, either Monday or Sunday. Default: Monday. Example: Sunday, if you want the week to start on a Sunday.
  asin: 'asin_example', # String | Filters the results by the ASIN that you specify. Specifying both ASIN and SKU returns an error. Do not include this filter if you want the response to include order metrics for all ASINs. Example: B0792R1RSN, if you want the response to include order metrics for only ASIN B0792R1RSN.
  sku: 'sku_example' # String | Filters the results by the SKU that you specify. Specifying both ASIN and SKU returns an error. Do not include this filter if you want the response to include order metrics for all SKUs. Example: TestSKU, if you want the response to include order metrics for only SKU TestSKU.
}

begin
  result = api_instance.get_order_metrics(marketplace_ids, interval, granularity, opts)
  p result
rescue AmzSpApi::SalesApiModel::ApiError => e
  puts "Exception when calling SalesApi->get_order_metrics: #{e}"
end
```

## Documentation for API Endpoints

All URIs are relative to *https://sellingpartnerapi-na.amazon.com/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AmzSpApi::SalesApiModel::SalesApi* | [**get_order_metrics**](docs/SalesApi.md#get_order_metrics) | **GET** /sales/v1/orderMetrics | 

## Documentation for Models

 - [AmzSpApi::SalesApiModel::Decimal](docs/Decimal.md)
 - [AmzSpApi::SalesApiModel::Error](docs/Error.md)
 - [AmzSpApi::SalesApiModel::ErrorList](docs/ErrorList.md)
 - [AmzSpApi::SalesApiModel::GetOrderMetricsResponse](docs/GetOrderMetricsResponse.md)
 - [AmzSpApi::SalesApiModel::Money](docs/Money.md)
 - [AmzSpApi::SalesApiModel::OrderMetricsInterval](docs/OrderMetricsInterval.md)
 - [AmzSpApi::SalesApiModel::OrderMetricsList](docs/OrderMetricsList.md)

## Documentation for Authorization

 All endpoints do not require authorization.

