# solicitations-api-model

AmzSpApi::SolicitationsApiModel - the Ruby gem for the Selling Partner API for Solicitations

With the Solicitations API you can build applications that send non-critical solicitations to buyers. You can get a list of solicitation types that are available for an order that you specify, then call an operation that sends a solicitation to the buyer for that order. Buyers cannot respond to solicitations sent by this API, and these solicitations do not appear in the Messaging section of Seller Central or in the recipient's Message Center. The Solicitations API returns responses that are formed according to the <a href=https://tools.ietf.org/html/draft-kelly-json-hal-08>JSON Hypertext Application Language</a> (HAL) standard.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v1
- Package version: 0.1.0
- Build package: io.swagger.codegen.v3.generators.ruby.RubyClientCodegen
For more information, please visit [https://sellercentral.amazon.com/gp/mws/contactus.html](https://sellercentral.amazon.com/gp/mws/contactus.html)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build solicitations-api-model.gemspec
```

Then either install the gem locally:

```shell
gem install ./solicitations-api-model-0.1.0.gem
```
(for development, run `gem install --dev ./solicitations-api-model-0.1.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'solicitations-api-model', '~> 0.1.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'solicitations-api-model', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'solicitations-api-model'

api_instance = AmzSpApi::SolicitationsApiModel::SolicitationsApi.new
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which a solicitation is sent.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.create_product_review_and_seller_feedback_solicitation(amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::SolicitationsApiModel::ApiError => e
  puts "Exception when calling SolicitationsApi->create_product_review_and_seller_feedback_solicitation: #{e}"
end

api_instance = AmzSpApi::SolicitationsApiModel::SolicitationsApi.new
amazon_order_id = 'amazon_order_id_example' # String | An Amazon order identifier. This specifies the order for which you want a list of available solicitation types.
marketplace_ids = ['marketplace_ids_example'] # Array<String> | A marketplace identifier. This specifies the marketplace in which the order was placed. Only one marketplace can be specified.


begin
  result = api_instance.get_solicitation_actions_for_order(amazon_order_id, marketplace_ids)
  p result
rescue AmzSpApi::SolicitationsApiModel::ApiError => e
  puts "Exception when calling SolicitationsApi->get_solicitation_actions_for_order: #{e}"
end
```

## Documentation for API Endpoints

All URIs are relative to *https://sellingpartnerapi-na.amazon.com/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AmzSpApi::SolicitationsApiModel::SolicitationsApi* | [**create_product_review_and_seller_feedback_solicitation**](docs/SolicitationsApi.md#create_product_review_and_seller_feedback_solicitation) | **POST** /solicitations/v1/orders/{amazonOrderId}/solicitations/productReviewAndSellerFeedback | 
*AmzSpApi::SolicitationsApiModel::SolicitationsApi* | [**get_solicitation_actions_for_order**](docs/SolicitationsApi.md#get_solicitation_actions_for_order) | **GET** /solicitations/v1/orders/{amazonOrderId} | 

## Documentation for Models

 - [AmzSpApi::SolicitationsApiModel::CreateProductReviewAndSellerFeedbackSolicitationResponse](docs/CreateProductReviewAndSellerFeedbackSolicitationResponse.md)
 - [AmzSpApi::SolicitationsApiModel::Error](docs/Error.md)
 - [AmzSpApi::SolicitationsApiModel::ErrorList](docs/ErrorList.md)
 - [AmzSpApi::SolicitationsApiModel::GetSchemaResponse](docs/GetSchemaResponse.md)
 - [AmzSpApi::SolicitationsApiModel::GetSchemaResponseLinks](docs/GetSchemaResponseLinks.md)
 - [AmzSpApi::SolicitationsApiModel::GetSolicitationActionResponse](docs/GetSolicitationActionResponse.md)
 - [AmzSpApi::SolicitationsApiModel::GetSolicitationActionResponseEmbedded](docs/GetSolicitationActionResponseEmbedded.md)
 - [AmzSpApi::SolicitationsApiModel::GetSolicitationActionResponseLinks](docs/GetSolicitationActionResponseLinks.md)
 - [AmzSpApi::SolicitationsApiModel::GetSolicitationActionsForOrderResponse](docs/GetSolicitationActionsForOrderResponse.md)
 - [AmzSpApi::SolicitationsApiModel::GetSolicitationActionsForOrderResponseEmbedded](docs/GetSolicitationActionsForOrderResponseEmbedded.md)
 - [AmzSpApi::SolicitationsApiModel::GetSolicitationActionsForOrderResponseLinks](docs/GetSolicitationActionsForOrderResponseLinks.md)
 - [AmzSpApi::SolicitationsApiModel::LinkObject](docs/LinkObject.md)
 - [AmzSpApi::SolicitationsApiModel::Schema](docs/Schema.md)
 - [AmzSpApi::SolicitationsApiModel::SolicitationsAction](docs/SolicitationsAction.md)

## Documentation for Authorization

 All endpoints do not require authorization.

